| hal_configure | R Documentation |
Set display, governance, and session defaults. Settings persist for the
duration of the R session via options().
hal_configure(
use_colors = NULL,
stream = NULL,
stream_speed = NULL,
default_model = NULL,
system_prompt = NULL,
eval_denylist = NULL,
credential_action = NULL,
eval_timeout = NULL,
prompt_timeout = NULL,
prompt_timeout_cold = NULL,
edit_in_place = NULL,
do_retries = NULL,
do_on_fail = NULL,
verify = NULL,
plot_vision = NULL,
permission_policy = NULL,
session_quiet = NULL,
init_quiet = NULL,
show_thoughts = NULL,
backend = NULL,
quiet = FALSE
)
use_colors |
Logical; enable ANSI color output (default: TRUE). |
stream |
Logical; enable streaming typewriter output (default: TRUE). |
stream_speed |
Character; |
default_model |
Character; default model identifier. |
system_prompt |
Character; custom system prompt. Use |
eval_denylist |
Character vector of function names blocked from
|
credential_action |
Character; action on credential detection:
|
eval_timeout |
Numeric; seconds for eval_r time limit (default: 30). |
prompt_timeout |
Numeric; seconds before aborting a resumed prompt on the Claude backend (default: 60). Has no effect on Copilot. |
prompt_timeout_cold |
Numeric; seconds before aborting the first (session-creating) prompt on the Claude backend (default: 180). The cold path pays for Node.js startup, AV scanning, and session provisioning on Windows and can exceed the warm timeout. |
edit_in_place |
Logical; when TRUE, |
do_retries |
Integer; max retry attempts for |
do_on_fail |
Character; what |
verify |
Logical; when TRUE (default), |
plot_vision |
Logical; when TRUE (default), plots drawn by |
permission_policy |
Character or function; how to handle tool
permission requests. |
session_quiet |
Logical; suppress informational messages from the
transport layer (CLI startup, handshake). Takes effect on next session
init (call |
init_quiet |
Logical; when TRUE, suppress the data transmission notice shown on first session init (default: FALSE). |
show_thoughts |
Logical; when TRUE, display the model's reasoning/thought
process before the response (default: FALSE). Takes effect on next session
init (call |
backend |
Character; transport backend: |
quiet |
Logical; suppress confirmation messages (default: FALSE). |
Invisibly returns a list of changes made.
hal_configure(stream = FALSE, do_retries = 1, quiet = TRUE)
hal_config()$stream
# unset again to restore the defaults
options(hal.stream = NULL, hal.do_retries = NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.