Plan mode (and occasionally Agent mode) asks the model to commit to a
structured plan, written to
~/.copilot/session-state/{sessionId}/plan.md. hal_plan() returns
the path so you can view or edit it directly.
Plan mode (and occasionally Agent mode) asks the model to commit to a
structured plan, written to
~/.copilot/session-state/{sessionId}/plan.md. hal_plan() returns
the path so you can view or edit it directly.